@@ -11,6 +11,7 @@ from copy import copy
 import matplotlib.pyplot as plt
 from .private_func import _preprocessing
 from .private_func import _get_report
+from .private_func import _corr2
 
 
 class simpletest():
@@ -36,10 +37,11 @@ class simpletest():
         if len(x) != len(y):
             print(F'mismatched length of x, y, len(x) == {len(x)} len(y) == {len(y)}')
             return
+
         factor, ret = _preprocessing(x, y)
         factor_mid = np.median(factor)
 
-        corr = self.corr(factor, ret)
+        corr = _corr2(factor, ret)
 
         output = {}
 
@@ -143,11 +145,12 @@ class simpletest():
             print(F'mismatched length of x, y, len(x) == {len(x)} len(y) == {len(y)}')
             return
 
-        if corr is None:
-            corr = self.corr(x, y)
-
         factor, ret = _preprocessing(x, y)
         indicator = factor.copy()
+
+        if corr is None:
+            corr = _corr2(factor, ret)
+
         if len(t_list) == 2:
             indicator.loc[factor > t_list[1]] = 1 * np.sign(corr) * 100.0
             indicator.loc[factor < t_list[0]] = -1 * np.sign(corr) * 100.0
@@ -218,7 +221,7 @@ class simpletest():
         else:
             y_name = 'y'
 
-        corr = self.corr(x, y)
+        corr = _corr2(x, y)
         x_, y_ = _preprocessing(x, y)
 
         sorted_idx = np.argsort(x_)
@@ -233,6 +236,7 @@ class simpletest():
 
         x_line = np.arange(0, len(x_))
         ax.plot(x_line, cdf_line, label=F'CDF - {y_name}')
+        ax.set_xlabel('Rank')
 
         if ax_twinx:
             ax_ = ax_twinx
@@ -243,6 +247,7 @@ class simpletest():
         ax_.axhline(0, ls='--', lw=1, color='r', alpha=0.3)
         if with_legend:
             ax_.legend(loc='lower right')
+        ax_.set_ylabel('Value')
 
         ax.text(x_line[peak_idx], cdf_line[peak_idx], 'factor val: {:.2f}'.format(peak))
 
@@ -345,7 +350,7 @@ class simpletest():
         output = pd.concat([x, y], axis=1).corr().iloc[0, 1]
         return output
 
-    def plot_composite(self, x, y, markout_periods=30, cdf_period2=5, fig=None, fig_return=False):
+    def plot_composite(self, x, y, markout_periods=30, cdf_period2=5, title=None, fig=None, fig_return=False):
         """
         x, y: prefer pd.Series
         x: factor
@@ -360,6 +365,9 @@ class simpletest():
         if fig is None:
             fig = plt.figure(figsize=(20, 20))
 
+        if title is not None:
+            plt.title(str(title))
+
         Y = pd.concat([y.rolling(i).sum().shift(-i + 1).rename(str(i)) \
                        for i in range(1, markout_periods + 1)], axis=1)
 
